@@ -1,13 +1,15 @@
 from .finding import Finding, FindingSeverity, FindingType
+from .label import Label, LabelType, EntityType
 from .block_event import BlockEvent
 from .transaction_event import TransactionEvent, TxEventBlock
+from .alert_event import AlertEvent
 from .block import Block
 from .transaction import Transaction
 from .receipt import Receipt, Log
 from .trace import Trace, TraceAction, TraceResult
 from .event_type import EventType
 from .network import Network
-from .utils import get_json_rpc_url, create_block_event, create_transaction_event, get_web3_provider, keccak256, get_transaction_receipt, get_alerts, fetch_jwt, decode_jwt, verify_jwt
+from .utils import get_json_rpc_url, create_block_event, create_transaction_event, create_alert_event, get_web3_provider, keccak256, get_transaction_receipt, get_alerts, fetch_jwt, decode_jwt, verify_jwt
 from web3 import Web3
 
 web3Provider = Web3(Web3.HTTPProvider(get_json_rpc_url()))
