@@ -2,7 +2,6 @@ import base64
 import sys
 import os
 from jsonc_parser.parser import JsoncParser
-import sha3
 import requests
 import datetime
 import time
@@ -93,12 +92,18 @@ def create_transaction_event(dict):
     return TransactionEvent(dict)
 
 
+def create_alert_event(dict):
+    from .alert_event import AlertEvent  # avoid circular import
+    return AlertEvent(dict)
+
+
 def get_alerts(dict):
     from .forta_graphql import AlertQueryOptions
     forta_api = "https://api.forta.network/graphql"
     headers = {"content-type": "application/json"}
     query_options = AlertQueryOptions(dict)
     payload = query_options.get_query()
+
     response = requests.request("POST", forta_api, json=payload, headers=headers)
 
     if response.status_code == 200:
@@ -106,9 +111,9 @@ def get_alerts(dict):
 
         if data:
             return AlertsResponse(data.get('alerts'))
-        return data
-
-    return response
+    else:
+        message = response.text
+        raise Exception(message)
 
 
 def assert_non_empty_string_in_dict(dict, key):
@@ -133,9 +138,7 @@ def hex_to_int(strVal):
 
 
 def keccak256(val):
-    hash = sha3.keccak_256()
-    hash.update(bytes(val, encoding='utf-8'))
-    return f'0x{hash.hexdigest()}'
+    return Web3.keccak(text=val).hex()
 
 def fetch_jwt(claims, expiresAt=None) -> str:
     host_name = 'forta-jwt-provider'
